Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Space ¶
func NewRemoteSpace ¶
NewSpace creates a structure that represents a remote space.
type SpaceInterface ¶
type SpaceInterface interface {
spc.Interspace
}
SpaceInterface contains all interfaces that can operate on a space.
type Template ¶
func CreateTemplate ¶
func CreateTemplate(fields ...interface{}) Template
CreateTemplate creates a structure that represents a template.
type TemplateInterface ¶
type TemplateInterface interface {
shr.Intertemplate
}
TemplateInterface contains all interfaces that can operate on a template.
type Tuple ¶
func CreateTuple ¶
func CreateTuple(fields ...interface{}) Tuple
CreateTuple creates a structure that represents a tuple.
type TupleInterface ¶
type TupleInterface interface {
shr.Intertuple
}
TupleInterface contains all interfaces that can operate on a tuple.
Click to show internal directories.
Click to hide internal directories.